==> python-convertertools_0.6.1.orig.tar.gz: convertertools-0.6.1/CHANGELOG.md <==
# Changelog

## v0.6.1 (2025-01-17)

### Fix


- Rebuild wheels (#19) ([`02019d3`](https://github.com/Bluetooth-Devices/convertertools/commit/02019d39ff0dd7cc1ba25024704cdeaf96f58c58))


## v0.6.0 (2025-01-17)

### Feature


- Add aarch64 wheels (#18) ([`acc4b49`](https://github.com/Bluetooth-Devices/convertertools/commit/acc4b49789b978c51aaf40727235be8de3eade49))


### Unknown



## v0.5.0 (2024-06-27)

### Feature


- Add pop_dict_set_if_none ([`455b2f6`](https://github.com/Bluetooth-Devices/convertertools/commit/455b2f6bfdf049071aabec1cb9793d846ecb57f1))


## v0.4.1 (2024-06-27)

### Fix


- Loosen version constrain for python ([`7c9aa8c`](https://github.com/Bluetooth-Devices/convertertools/commit/7c9aa8c89ec419a7088815868a6dbad04a6f1ff8))


## v0.4.0 (2024-06-27)

### Feature


- Python 3.10 support ([`8ed37cc`](https://github.com/Bluetooth-Devices/convertertools/commit/8ed37cce81ded6e129edece08e1257db6ddcb7e1))


## v0.3.0 (2024-06-27)

### Fix


- Drop win32 from ci as there is nothing specific here ([`423d493`](https://github.com/Bluetooth-Devices/convertertools/commit/423d49361dd2e64437b5d9bac04328ad437a237e))


### Feature


- Expose pop functions ([`7e475f8`](https://github.com/Bluetooth-Devices/convertertools/commit/7e475f8bd40ac716d42bfa3c8800e6241e9de7ff))


- Add readme ([`367485d`](https://github.com/Bluetooth-Devices/convertertools/commit/367485d10e1a8b495b124115e91cb415ddf85e6c))


- Test with cython and no cython ([`79ca20a`](https://github.com/Bluetooth-Devices/convertertools/commit/79ca20aeb795c7dab851c1ae4644f92b86f5a6fb))


## v0.2.2 (2024-06-27)

### Unknown



### Fix


- Add pop functions ([`b491626`](https://github.com/Bluetooth-Devices/convertertools/commit/b491626bb0cc84f82a76bc8462b1ed00009ebfb0))


## v0.2.1 (2024-06-27)

### Unknown



### Fix


- Wheel builds ([`11dc333`](https://github.com/Bluetooth-Devices/convertertools/commit/11dc333b4e0bbedb9fa9feebe602a8e00f4ace3b))


## v0.2.0 (2024-06-27)

### Feature


- Optional delete ([`3f1345b`](https://github.com/Bluetooth-Devices/convertertools/commit/3f1345ba27e8fdbc48b3a74b8b32b5a46f72b73b))


- Shorten names ([`1c93006`](https://github.com/Bluetooth-Devices/convertertools/commit/1c930065f05d985907e873b53f8260292641f912))


### Unknown



## v0.1.0 (2024-06-27)

### Feature


- Add delete tools ([`c3d4add`](https://github.com/Bluetooth-Devices/convertertools/commit/c3d4add051fc02914443cc6e1cced2c8b3b2145c))


- Init ([`43ec5bd`](https://github.com/Bluetooth-Devices/convertertools/commit/43ec5bd6479aafd7b9225b9cce762ec3bbe3e7ce))


### Unknown



## v0.0.0 (2024-06-27)

### Documentation


- Add @bluetooth-devices as a contributor ([`cca2f2c`](https://github.com/Bluetooth-Devices/convertertools/commit/cca2f2c7d16dd6d9a9120b91e12418830b89a28b))

==> python-convertertools_1.1.0.orig.tar.gz: convertertools-1.1.0/CHANGELOG.md <==
# Changelog

## v1.1.0 (2025-10-04)

### Features


- Update poetry to v2 ([`1f5e261`](https://github.com/Bluetooth-Devices/convertertools/commit/1f5e2614bae56ffb4bb020c8544517b321631842))


## v1.0.0 (2025-10-04)

## v0.6.1 (2025-01-17)

### Bug fixes


- Rebuild wheels ([`02019d3`](https://github.com/Bluetooth-Devices/convertertools/commit/02019d39ff0dd7cc1ba25024704cdeaf96f58c58))


## v0.6.0 (2025-01-17)

### Features


- Add aarch64 wheels ([`acc4b49`](https://github.com/Bluetooth-Devices/convertertools/commit/acc4b49789b978c51aaf40727235be8de3eade49))


### Unknown



## v0.5.0 (2024-06-27)

### Features


- Add pop_dict_set_if_none ([`455b2f6`](https://github.com/Bluetooth-Devices/convertertools/commit/455b2f6bfdf049071aabec1cb9793d846ecb57f1))


## v0.4.1 (2024-06-27)

### Bug fixes


- Loosen version constrain for python ([`7c9aa8c`](https://github.com/Bluetooth-Devices/convertertools/commit/7c9aa8c89ec419a7088815868a6dbad04a6f1ff8))


## v0.4.0 (2024-06-27)

### Features


- Python 3.10 support ([`8ed37cc`](https://github.com/Bluetooth-Devices/convertertools/commit/8ed37cce81ded6e129edece08e1257db6ddcb7e1))


## v0.3.0 (2024-06-27)

### Bug fixes


- Drop win32 from ci as there is nothing specific here ([`423d493`](https://github.com/Bluetooth-Devices/convertertools/commit/423d49361dd2e64437b5d9bac04328ad437a237e))


### Features


- Expose pop functions ([`7e475f8`](https://github.com/Bluetooth-Devices/convertertools/commit/7e475f8bd40ac716d42bfa3c8800e6241e9de7ff))


- Add readme ([`367485d`](https://github.com/Bluetooth-Devices/convertertools/commit/367485d10e1a8b495b124115e91cb415ddf85e6c))


- Test with cython and no cython ([`79ca20a`](https://github.com/Bluetooth-Devices/convertertools/commit/79ca20aeb795c7dab851c1ae4644f92b86f5a6fb))


## v0.2.2 (2024-06-27)

## v0.2.1 (2024-06-27)

### Bug fixes


- Add pop functions ([`b491626`](https://github.com/Bluetooth-Devices/convertertools/commit/b491626bb0cc84f82a76bc8462b1ed00009ebfb0))


## v0.2.0 (2024-06-27)

### Bug fixes


- Wheel builds ([`11dc333`](https://github.com/Bluetooth-Devices/convertertools/commit/11dc333b4e0bbedb9fa9feebe602a8e00f4ace3b))


### Features


- Optional delete ([`3f1345b`](https://github.com/Bluetooth-Devices/convertertools/commit/3f1345ba27e8fdbc48b3a74b8b32b5a46f72b73b))


## v0.1.0 (2024-06-27)

### Features


- Shorten names ([`1c93006`](https://github.com/Bluetooth-Devices/convertertools/commit/1c930065f05d985907e873b53f8260292641f912))


- Add delete tools ([`c3d4add`](https://github.com/Bluetooth-Devices/convertertools/commit/c3d4add051fc02914443cc6e1cced2c8b3b2145c))


## v0.0.0 (2024-06-27)

### Features


- Init ([`43ec5bd`](https://github.com/Bluetooth-Devices/convertertools/commit/43ec5bd6479aafd7b9225b9cce762ec3bbe3e7ce))


### Documentation


- Add @bluetooth-devices as a contributor ([`cca2f2c`](https://github.com/Bluetooth-Devices/convertertools/commit/cca2f2c7d16dd6d9a9120b91e12418830b89a28b))
